use domain::{
    dto::account::{AuthenticateGooleAccountReq, AuthenticateWithPassword, RefreshToken},
    vo::account::{LoginAccount, RefreshTokenResult},
};
use library::{context::Context, extractor::body_extractor::JsonBody, model::response::ResResult};
use macros::post;

use crate::service;

/// google账号登录
#[post("/account/google")]
pub async fn authenticate_google(
    context: Context,
    JsonBody(req): JsonBody<AuthenticateGooleAccountReq>,
) -> ResResult<LoginAccount> {
    service::account_service::authenticate_google(context, req).await
}

/// 账号密码登录
#[post("/account/sys")]
pub async fn authenticate_with_password(
    context: Context,
    JsonBody(req): JsonBody<AuthenticateWithPassword>,
) -> ResResult<LoginAccount> {
    service::sys_account_service::authenticate_with_password(context, req).await
}

/// 刷新token
#[post("/account/refresh-token")]
pub async fn refresh_account_token(
    context: Context,
    JsonBody(refresh_token): JsonBody<RefreshToken>,
) -> ResResult<RefreshTokenResult> {
    service::account_service::refresh_token(context, refresh_token.token).await
}

/// 添加管理员账号
#[allow(dead_code)]
pub async fn add_account() -> ResResult<()> {
    service::sys_account_service::add_account().await
}
